//******************************************************************************
//  MSP430G2x31 Demo - ADC10, A1 mrse, Vref+ = Vcc, P1.0 g, ha A1 > 0.5*Vcc
//
//  Programlers: Egycsatorns mrs az A1 mebeneten, Vcc referencival.
//  A konverzit szoftveresen indtjuk ADC10SC '1'-be lltsval - ADC10SC
//  automatikusan trldik a konverzi vgn. ADC10 sajt oszcilltora temezi
//  a mintavtelezst (64 rajel peridus) s a konverzit.
//  A fprogram vgtelen ciklusban a mikrovezrl LPM0 energiatakarkos mdban 
//  vrakozik, amg a konverzi be nem fejezdik. Az ADC megszaktsnak
//  kiszolglsakor bresztjk fel jra a mikrovezrlt. 
//  Ha A1 > 0.5*Vcc, akkor a P1.0-ra kttt LED vilgt, egybknt lekapcsoljuk.
//
//                MSP430G2x31
//             -----------------
//         /|\|              XIN|-
//          | |                 |
//          --|RST          XOUT|-
//            |                 |
//        >---|P1.1/A1      P1.0|-->LED
//
//  Szerz: D. Dang, Texas Instruments Inc., Oct 2010 (msp430g2x31_adc10_01.c)
//  Magyar vltozat: I. Cserny, MTA ATOMKI, Jan 2013 (4_adc_interrupt.c)
//                   IAR Embedded Workbench Version: 5.51
//******************************************************************************
#include "msp430.h"

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Letiltjuk a watchdog idztt
  ADC10CTL0 = ADC10SHT_3                    // mintavtel: 64 rats
             | ADC10ON                      // Az ADC bekapcsolsa
             | SREF_0                       // VR+ = AVCC s VR- = AVSS  
             | ADC10IE;                     // ADC10 megszakts engedlyezse   
  ADC10CTL1 = ADC10SSEL_0 | INCH_1;         // ADC10OSC az rajel, A1 a bemenet
  ADC10AE0 |= BIT1;                         // P1.1 analg funkci engedlyezse
  P1DIR |= BIT0;                            // P1.0 kimenet legyen (LED1)

  for (;;)
  {
    ADC10CTL0 |= ENC + ADC10SC;             // Konverzi engedlyezse s indtsa
    __low_power_mode_0();                   // Alvs a konverzi vgig
    if (ADC10MEM < 0x1FF)                   // Ha A1 < 0.5*Vcc 
      P1OUT &= ~0x01;                       // P1.0 LED1-et kikapcsoljuk
    else
      P1OUT |= 0x01;                        // P1.0 LED1-et bekapcsoljuk
  }
}

//--- ADC10 megszaktskiszolgl eljrs -----
#pragma vector=ADC10_VECTOR
__interrupt void ADC10_ISR(void)
{
  __low_power_mode_off_on_exit();           // Felbresztjk az alv CPU-t
}
