/**********************************************************************
 *  Launchpad demprogram: ADC_pwm2
 *
 * A P1.6 kimenetre kttt zld LED fnyerejt impulzus-szlessg
 * modulcival (PWM) vltoztatjuk, melyhez a vezrl jelet a P1.5
 * bemenetre kapcsolt analg feszltsgjel adja, amit a beptett
 * 10 bites ADC-vel mrjk meg. Az ADC konverzi rtke szabja meg 
 * a kitlts mrtkt. 
 *
 * Az ADC referencia feszltsge a tpfeszltsg lesz (VSS, VCC).
 * A PWM frekvencia kb. 125 Hz (az alaprtelmezett DCO frekvencit
 * 8-cal s 1024-gyel osztjuk le.
 * A PWM kitlts frisstse az ADC megszaktsokban trtnik.
 * A konverzikat a CCR0 csatorna kimen jelvel indtjuk (OUT0).
 *
 * Hardver felttelek:
 *  - MSP430 Launchpad krtya (MSP430G2231, MSP430G2452 vagy MSP430G2553)
 *  - Analg potmter, csszkja a P1.5-re ktve (kt vge pedig 
 *    VCC-re s VSS-re.
 *
 *       MSP430G2231, MSP430G2452 vagy MSP430G2553
 *             -----------------
 *    Vcc  /|\|              XIN|-
 *     |    | |                 |
 *     _    --|RST          XOUT|-
 *    | |     |                 |
 *    | |<----|P1.5         P1.6|--> LED
 *    |_|     |                 |
 *     |
 *    Vss
 * Szerz: J H Davies, 2007-08-30; IAR Kickstart version 3.42A
 * Launchpad-ra adaptlta: I Cserny, 2012-11-23; IAR version 5.51
 **********************************************************************/
#include "io430.h"

void main (void) {
    WDTCTL = WDTPW | WDTHOLD;          // Letiltjuk a watchdog idztt
    P1OUT = 0;                         // A nem hasznlt kimeneteket lehzzuk
    P1DIR = ~(BIT2+BIT3+BIT5);         // Csak RXD, SW2 s AN5 legyen bemenet
    P1SEL |= BIT6;                     // P1.6 legyen TA0.1 kimenet
//-- P1.3 bels felhzs bekapcsolsa ------
    P1OUT |= BIT3;                     // Felfel hzzuk, nem lefel
    P1REN |= BIT3;                     // Bels felhzs bekapcsolsa P1.3-ra
//-- Analg bemenet engedlyezse ----------    
    ADC10AE0 = BIT5;                   // Enable analog input on AN5/P1.5
//-- Timer_A PWM 125Hz, OUT1 kimeneten, SMCLK/8 rajellel, "Felfel szmlls"
    TACCR0 = BITA - 1;                 // A peridus ADC10-hez illeszked (1023)
    TACCTL0 = OUTMOD_4;                // Toggle md (OUT0 indtja az ADC-t)
    TACCR1 = BIT9;                     // CCR1 indulskor 50%-ra (512)
    TACCTL1 = OUTMOD_7;                // Reset/set PWM md belltsa
    TACTL = TASSEL_2 |                 // SMCLK az rajel forrsa
                ID_3 |                 // 1:8 oszts bekapcsolsa
                MC_1 |                 // Felfel szmll md
                TACLR;                 // TAR trlse
//-- ADC  konfigurls ---------------------
    ADC10CTL0 = ADC10SHT_0             // mintavtel: 4 rats
               | ADC10ON               // Az ADC bekapcsolsa
               | SREF_0                // VR+ = AVCC s VR- = AVSS
               | ADC10IE;              // Programmegszakts engedlyezse
    ADC10CTL1 = INCH_5                 // A5 csatorna kivlasztsa
               | SHS_2                 // Hatdveres triggerels (TA0.0)     
               | ADC10SSEL_0           // ADC10OSC adja az rajelet (~5 MHz)
               | CONSEQ_2;             // Ismtelt egycsatorns konverzi
    ADC10CTL0 |= ENC;                  // A konverzi engedlyezse
        __low_power_mode_0();          // A tovbbi tevkenysg megszaktsban
}

//----------------------------------------------------------------------
// ADC10 megszakts kiszolglsa: PWM kitlts aktualizlsa
//----------------------------------------------------------------------
#pragma vector = ADC10_VECTOR
__interrupt void ADC10_ISR (void)      // A jelzbit automatikusan trldik
{
    TACCR1 = ADC10MEM;                 // PWM kitlts = ADC konverzi eredmnye
}